using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using devDept.Eyeshot.Entities;
using devDept.Eyeshot;
using devDept.Geometry;
using System.Collections;

namespace WindowsApplication1
{
    public partial class Form1 : Form
    {

        public Form1()
        {
            InitializeComponent();

            // viewportLayout1.Unlock(""); // For more details see 'Product Activation' topic in the documentation.

            selectionComboBox.SelectedIndex = 0;
            selectCheckBox.Checked = true;

        }

        private void Form1_Load(object sender, EventArgs e)
        {
            DrawQuadsVBO(viewportLayout1);
        }

        private static void DrawQuadsVBO(ViewportLayout vp)
        {
            List<IndexTriangle> triangles = new List<IndexTriangle>();
            List<Vector3D> normals = new List<Vector3D>();

            // Create a mesh with 2 quads
            Point3D[] ptQuads = new Point3D[8]
            {
                new Point3D(0, 0, 0), new Point3D(10, 0, 0), new Point3D(10, 10, 0), new Point3D(0, 10, 0),
                new Point3D(15, 0, 0), new Point3D(25, 0, 0), new Point3D(25, 10, 0), new Point3D(15, 10, 0),
            };

            int nQuads = 2;

            for (int i = 0, countVertices = 0; i < nQuads; i++, countVertices += 4)
            {
                // get the vertices coordinates for the quad
                Point3D pt1 = ptQuads[countVertices];
                Point3D pt2 = ptQuads[countVertices + 1];
                Point3D pt3 = ptQuads[countVertices + 2];
                Point3D pt4 = ptQuads[countVertices + 3];

                triangles.Add(new IndexTriangle(countVertices, countVertices + 1, countVertices + 2));
                triangles.Add(new IndexTriangle(countVertices, countVertices + 2, countVertices + 3));

                Vector3D diff = Vector3D.Subtract(pt2, pt1);
                Vector3D diff2 = Vector3D.Subtract(pt3, pt1);

                Vector3D normal = Vector3D.Cross(diff, diff2);
                normal.Normalize();

                normals.Add(normal); // Add just one normal because I'm using quads internally

                vp.ZoomFit();
            }

            // Create the MyMesh object and add it to the ViewportLayout.
            Mesh mesh = new MyMesh(vp, meshNatureType.Plain);
            mesh.Vertices = ptQuads;
            mesh.Triangles = triangles.ToArray();
            mesh.Normals = normals.ToArray();
            mesh.ColorMethod = devDept.Eyeshot.Entities.colorMethodType.byEntity;
            mesh.Color = Color.Red;
            mesh.LightWeight = true;
            mesh.EdgeStyle = meshEdgeStyleType.None;

            vp.Entities.Add(mesh);

            vp.ZoomFit();
        }

        private void wireframeButton_CheckedChanged(object sender, EventArgs e)
        {
            viewportLayout1.DisplayMode = displayType.Wireframe;
            viewportLayout1.Invalidate();
        }

        private void shadedButton_CheckedChanged(object sender, EventArgs e)
        {
            viewportLayout1.DisplayMode = displayType.Shaded;
            viewportLayout1.Invalidate();
        }

        private void renderedButton_CheckedChanged(object sender, EventArgs e)
        {
            viewportLayout1.DisplayMode = displayType.Wireframe;
            viewportLayout1.Invalidate();
        }

        private void hiddenLinesButton_CheckedChanged(object sender, EventArgs e)
        {
            viewportLayout1.DisplayMode = displayType.HiddenLines;
            viewportLayout1.Invalidate();
        }

        private void selectionComboBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (selectCheckBox.Checked)

                Selection();

            else

                viewportLayout1.ActionMode = actionType.None;
        }

        private void Selection()
        {
            switch (selectionComboBox.SelectedIndex)
            {
                case 0: // by pick
                    viewportLayout1.ActionMode = actionType.SelectByPick;
                    break;

                case 1: // by box
                    viewportLayout1.ActionMode = actionType.SelectByBox;
                    break;

                case 2: // by poly
                    viewportLayout1.ActionMode = actionType.SelectByPolygon;
                    break;

                case 3: // by box enclosed
                    viewportLayout1.ActionMode = actionType.SelectByBoxEnclosed;
                    break;

                case 4: // by poly enclosed
                    viewportLayout1.ActionMode = actionType.SelectByPolygonEnclosed;
                    break;

                case 5: // visible by pick
                    viewportLayout1.ActionMode = actionType.SelectVisibleByPick;
                    break;

                case 6: // visible by box
                    viewportLayout1.ActionMode = actionType.SelectVisibleByBox;
                    break;

                case 7: // visible by poly
                    viewportLayout1.ActionMode = actionType.SelectVisibleByPolygon;
                    break;

                case 8: // visible by pick label
                    viewportLayout1.ActionMode = actionType.SelectVisibleByPickLabel;
                    break;

                default:
                    viewportLayout1.ActionMode = actionType.None;
                    break;
            }
        }

        private void selectCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            if (selectCheckBox.Checked)

                Selection();

            else

                viewportLayout1.ActionMode = actionType.None;

        }
                
    }

}